@@ -16,28 +16,30 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.dataflow_v1beta3.services.metrics_v1_beta3 import pagers
 from google.cloud.dataflow_v1beta3.types import metrics
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import MetricsV1Beta3Transport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, MetricsV1Beta3Transport
 from .transports.grpc import MetricsV1Beta3GrpcTransport
 from .transports.grpc_asyncio import MetricsV1Beta3GrpcAsyncIOTransport
 
@@ -56,7 +58,10 @@ class MetricsV1Beta3ClientMeta(type):
     _transport_registry["grpc"] = MetricsV1Beta3GrpcTransport
     _transport_registry["grpc_asyncio"] = MetricsV1Beta3GrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[MetricsV1Beta3Transport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[MetricsV1Beta3Transport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -163,7 +168,9 @@ class MetricsV1Beta3Client(metaclass=MetricsV1Beta3ClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -176,9 +183,13 @@ class MetricsV1Beta3Client(metaclass=MetricsV1Beta3ClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -187,9 +198,13 @@ class MetricsV1Beta3Client(metaclass=MetricsV1Beta3ClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -198,9 +213,13 @@ class MetricsV1Beta3Client(metaclass=MetricsV1Beta3ClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -209,10 +228,14 @@ class MetricsV1Beta3Client(metaclass=MetricsV1Beta3ClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -404,7 +427,6 @@ class MetricsV1Beta3Client(metaclass=MetricsV1Beta3ClientMeta):
         can only request the status of jobs that are running in
         ``us-central1``.
 
-
         .. code-block:: python
 
             from google.cloud import dataflow_v1beta3
@@ -459,8 +481,25 @@ class MetricsV1Beta3Client(metaclass=MetricsV1Beta3ClientMeta):
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_job_metrics]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -478,7 +517,6 @@ class MetricsV1Beta3Client(metaclass=MetricsV1Beta3ClientMeta):
         EXPERIMENTAL.  This API is subject to change or removal
         without notice.
 
-
         .. code-block:: python
 
             from google.cloud import dataflow_v1beta3
@@ -531,13 +569,33 @@ class MetricsV1Beta3Client(metaclass=MetricsV1Beta3ClientMeta):
             self._transport.get_job_execution_details
         ]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.GetJobExecutionDetailsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -557,7 +615,6 @@ class MetricsV1Beta3Client(metaclass=MetricsV1Beta3ClientMeta):
         EXPERIMENTAL.  This API is subject to change or removal
         without notice.
 
-
         .. code-block:: python
 
             from google.cloud import dataflow_v1beta3
@@ -611,13 +668,34 @@ class MetricsV1Beta3Client(metaclass=MetricsV1Beta3ClientMeta):
             self._transport.get_stage_execution_details
         ]
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("project_id", request.project_id),
+                    ("location", request.location),
+                    ("job_id", request.job_id),
+                    ("stage_id", request.stage_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.GetStageExecutionDetailsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
