@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,12 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.rpc import status_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.dataflow_v1beta3.types import environment as gd_environment
 from google.cloud.dataflow_v1beta3.types import jobs
-from google.rpc import status_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.dataflow.v1beta3",
@@ -72,7 +71,11 @@ class LaunchFlexTemplateResponse(proto.Message):
             launched.
     """
 
-    job = proto.Field(proto.MESSAGE, number=1, message=jobs.Job,)
+    job = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=jobs.Job,
+    )
 
 
 class ContainerSpec(proto.Message):
@@ -91,17 +94,37 @@ class ContainerSpec(proto.Message):
             Default runtime environment for the job.
     """
 
-    image = proto.Field(proto.STRING, number=1,)
-    metadata = proto.Field(proto.MESSAGE, number=2, message="TemplateMetadata",)
-    sdk_info = proto.Field(proto.MESSAGE, number=3, message="SDKInfo",)
+    image = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    metadata = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="TemplateMetadata",
+    )
+    sdk_info = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="SDKInfo",
+    )
     default_environment = proto.Field(
-        proto.MESSAGE, number=4, message="FlexTemplateRuntimeEnvironment",
+        proto.MESSAGE,
+        number=4,
+        message="FlexTemplateRuntimeEnvironment",
     )
 
 
 class LaunchFlexTemplateParameter(proto.Message):
     r"""Launch FlexTemplate Parameter.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         job_name (str):
             Required. The job name to use for the created
@@ -109,12 +132,16 @@ class LaunchFlexTemplateParameter(proto.Message):
             same as the existing running job.
         container_spec (google.cloud.dataflow_v1beta3.types.ContainerSpec):
             Spec about the container image to launch.
+
+            This field is a member of `oneof`_ ``template``.
         container_spec_gcs_path (str):
             Cloud Storage path to a file with json
             serialized ContainerSpec as content.
-        parameters (Sequence[google.cloud.dataflow_v1beta3.types.LaunchFlexTemplateParameter.ParametersEntry]):
+
+            This field is a member of `oneof`_ ``template``.
+        parameters (Mapping[str, str]):
             The parameters for FlexTemplate. Ex. {"num_workers":"5"}
-        launch_options (Sequence[google.cloud.dataflow_v1beta3.types.LaunchFlexTemplateParameter.LaunchOptionsEntry]):
+        launch_options (Mapping[str, str]):
             Launch options for this flex template job.
             This is a common set of options across languages
             and templates. This should not be used to pass
@@ -126,23 +153,50 @@ class LaunchFlexTemplateParameter(proto.Message):
             Set this to true if you are sending a request
             to update a running streaming job. When set, the
             job name should be the same as the running job.
-        transform_name_mappings (Sequence[google.cloud.dataflow_v1beta3.types.LaunchFlexTemplateParameter.TransformNameMappingsEntry]):
+        transform_name_mappings (Mapping[str, str]):
             Use this to pass transform_name_mappings for streaming
             update jobs. Ex:{"oldTransformName":"newTransformName",...}'
     """
 
-    job_name = proto.Field(proto.STRING, number=1,)
+    job_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     container_spec = proto.Field(
-        proto.MESSAGE, number=4, oneof="template", message="ContainerSpec",
+        proto.MESSAGE,
+        number=4,
+        oneof="template",
+        message="ContainerSpec",
+    )
+    container_spec_gcs_path = proto.Field(
+        proto.STRING,
+        number=5,
+        oneof="template",
+    )
+    parameters = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    launch_options = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=6,
     )
-    container_spec_gcs_path = proto.Field(proto.STRING, number=5, oneof="template",)
-    parameters = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    launch_options = proto.MapField(proto.STRING, proto.STRING, number=6,)
     environment = proto.Field(
-        proto.MESSAGE, number=7, message="FlexTemplateRuntimeEnvironment",
+        proto.MESSAGE,
+        number=7,
+        message="FlexTemplateRuntimeEnvironment",
+    )
+    update = proto.Field(
+        proto.BOOL,
+        number=8,
+    )
+    transform_name_mappings = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=9,
     )
-    update = proto.Field(proto.BOOL, number=8,)
-    transform_name_mappings = proto.MapField(proto.STRING, proto.STRING, number=9,)
 
 
 class FlexTemplateRuntimeEnvironment(proto.Message):
@@ -185,7 +239,7 @@ class FlexTemplateRuntimeEnvironment(proto.Message):
             or "regions/REGION/subnetworks/SUBNETWORK". If the
             subnetwork is located in a Shared VPC network, you must use
             the complete URL.
-        additional_user_labels (Sequence[google.cloud.dataflow_v1beta3.types.FlexTemplateRuntimeEnvironment.AdditionalUserLabelsEntry]):
+        additional_user_labels (Mapping[str, str]):
             Additional user labels to be specified for the job. Keys and
             values must follow the restrictions specified in the
             `labeling
@@ -228,30 +282,122 @@ class FlexTemplateRuntimeEnvironment(proto.Message):
             to use for the 'worker harness. Default is the
             container for the version of the SDK. Note this
             field is only valid for portable pipelines.
+        disk_size_gb (int):
+            Worker disk size, in gigabytes.
+        autoscaling_algorithm (google.cloud.dataflow_v1beta3.types.AutoscalingAlgorithm):
+            The algorithm to use for autoscaling
+        dump_heap_on_oom (bool):
+            If true, save a heap dump before killing a
+            thread or process which is GC thrashing or out
+            of memory. The location of the heap file will
+            either be echoed back to the user, or the user
+            will be given the opportunity to download the
+            heap file.
+        save_heap_dumps_to_gcs_path (str):
+            Cloud Storage bucket (directory) to upload heap dumps to the
+            given location. Enabling this implies that heap dumps should
+            be generated on OOM (dump_heap_on_oom is set to true).
+        launcher_machine_type (str):
+            The machine type to use for launching the
+            job. The default is n1-standard-1.
     """
 
-    num_workers = proto.Field(proto.INT32, number=1,)
-    max_workers = proto.Field(proto.INT32, number=2,)
-    zone = proto.Field(proto.STRING, number=3,)
-    service_account_email = proto.Field(proto.STRING, number=4,)
-    temp_location = proto.Field(proto.STRING, number=5,)
-    machine_type = proto.Field(proto.STRING, number=6,)
-    additional_experiments = proto.RepeatedField(proto.STRING, number=7,)
-    network = proto.Field(proto.STRING, number=8,)
-    subnetwork = proto.Field(proto.STRING, number=9,)
-    additional_user_labels = proto.MapField(proto.STRING, proto.STRING, number=10,)
-    kms_key_name = proto.Field(proto.STRING, number=11,)
+    num_workers = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    max_workers = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    zone = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    service_account_email = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    temp_location = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    machine_type = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    additional_experiments = proto.RepeatedField(
+        proto.STRING,
+        number=7,
+    )
+    network = proto.Field(
+        proto.STRING,
+        number=8,
+    )
+    subnetwork = proto.Field(
+        proto.STRING,
+        number=9,
+    )
+    additional_user_labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=10,
+    )
+    kms_key_name = proto.Field(
+        proto.STRING,
+        number=11,
+    )
     ip_configuration = proto.Field(
-        proto.ENUM, number=12, enum=gd_environment.WorkerIPAddressConfiguration,
+        proto.ENUM,
+        number=12,
+        enum=gd_environment.WorkerIPAddressConfiguration,
+    )
+    worker_region = proto.Field(
+        proto.STRING,
+        number=13,
+    )
+    worker_zone = proto.Field(
+        proto.STRING,
+        number=14,
+    )
+    enable_streaming_engine = proto.Field(
+        proto.BOOL,
+        number=15,
     )
-    worker_region = proto.Field(proto.STRING, number=13,)
-    worker_zone = proto.Field(proto.STRING, number=14,)
-    enable_streaming_engine = proto.Field(proto.BOOL, number=15,)
     flexrs_goal = proto.Field(
-        proto.ENUM, number=16, enum=gd_environment.FlexResourceSchedulingGoal,
+        proto.ENUM,
+        number=16,
+        enum=gd_environment.FlexResourceSchedulingGoal,
+    )
+    staging_location = proto.Field(
+        proto.STRING,
+        number=17,
+    )
+    sdk_container_image = proto.Field(
+        proto.STRING,
+        number=18,
+    )
+    disk_size_gb = proto.Field(
+        proto.INT32,
+        number=20,
+    )
+    autoscaling_algorithm = proto.Field(
+        proto.ENUM,
+        number=21,
+        enum=gd_environment.AutoscalingAlgorithm,
+    )
+    dump_heap_on_oom = proto.Field(
+        proto.BOOL,
+        number=22,
+    )
+    save_heap_dumps_to_gcs_path = proto.Field(
+        proto.STRING,
+        number=23,
+    )
+    launcher_machine_type = proto.Field(
+        proto.STRING,
+        number=24,
     )
-    staging_location = proto.Field(proto.STRING, number=17,)
-    sdk_container_image = proto.Field(proto.STRING, number=18,)
 
 
 class LaunchFlexTemplateRequest(proto.Message):
@@ -273,12 +419,23 @@ class LaunchFlexTemplateRequest(proto.Message):
             actually executed. Defaults to false.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     launch_parameter = proto.Field(
-        proto.MESSAGE, number=2, message="LaunchFlexTemplateParameter",
+        proto.MESSAGE,
+        number=2,
+        message="LaunchFlexTemplateParameter",
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    validate_only = proto.Field(
+        proto.BOOL,
+        number=4,
     )
-    location = proto.Field(proto.STRING, number=3,)
-    validate_only = proto.Field(proto.BOOL, number=4,)
 
 
 class RuntimeEnvironment(proto.Message):
@@ -310,7 +467,8 @@ class RuntimeEnvironment(proto.Message):
             The machine type to use for the job. Defaults
             to the value from the template if not specified.
         additional_experiments (Sequence[str]):
-            Additional experiment flags for the job.
+            Additional experiment flags for the job, specified with the
+            ``--experiments`` option.
         network (str):
             Network to which VMs will be assigned.  If
             empty or unspecified, the service will use the
@@ -323,7 +481,7 @@ class RuntimeEnvironment(proto.Message):
             or "regions/REGION/subnetworks/SUBNETWORK". If the
             subnetwork is located in a Shared VPC network, you must use
             the complete URL.
-        additional_user_labels (Sequence[google.cloud.dataflow_v1beta3.types.RuntimeEnvironment.AdditionalUserLabelsEntry]):
+        additional_user_labels (Mapping[str, str]):
             Additional user labels to be specified for the job. Keys and
             values should follow the restrictions specified in the
             `labeling
@@ -357,24 +515,72 @@ class RuntimeEnvironment(proto.Message):
             job.
     """
 
-    num_workers = proto.Field(proto.INT32, number=11,)
-    max_workers = proto.Field(proto.INT32, number=1,)
-    zone = proto.Field(proto.STRING, number=2,)
-    service_account_email = proto.Field(proto.STRING, number=3,)
-    temp_location = proto.Field(proto.STRING, number=4,)
-    bypass_temp_dir_validation = proto.Field(proto.BOOL, number=5,)
-    machine_type = proto.Field(proto.STRING, number=6,)
-    additional_experiments = proto.RepeatedField(proto.STRING, number=7,)
-    network = proto.Field(proto.STRING, number=8,)
-    subnetwork = proto.Field(proto.STRING, number=9,)
-    additional_user_labels = proto.MapField(proto.STRING, proto.STRING, number=10,)
-    kms_key_name = proto.Field(proto.STRING, number=12,)
+    num_workers = proto.Field(
+        proto.INT32,
+        number=11,
+    )
+    max_workers = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    zone = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    service_account_email = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    temp_location = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    bypass_temp_dir_validation = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
+    machine_type = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    additional_experiments = proto.RepeatedField(
+        proto.STRING,
+        number=7,
+    )
+    network = proto.Field(
+        proto.STRING,
+        number=8,
+    )
+    subnetwork = proto.Field(
+        proto.STRING,
+        number=9,
+    )
+    additional_user_labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=10,
+    )
+    kms_key_name = proto.Field(
+        proto.STRING,
+        number=12,
+    )
     ip_configuration = proto.Field(
-        proto.ENUM, number=14, enum=gd_environment.WorkerIPAddressConfiguration,
+        proto.ENUM,
+        number=14,
+        enum=gd_environment.WorkerIPAddressConfiguration,
+    )
+    worker_region = proto.Field(
+        proto.STRING,
+        number=15,
+    )
+    worker_zone = proto.Field(
+        proto.STRING,
+        number=16,
+    )
+    enable_streaming_engine = proto.Field(
+        proto.BOOL,
+        number=17,
     )
-    worker_region = proto.Field(proto.STRING, number=15,)
-    worker_zone = proto.Field(proto.STRING, number=16,)
-    enable_streaming_engine = proto.Field(proto.BOOL, number=17,)
 
 
 class ParameterMetadata(proto.Message):
@@ -398,18 +604,41 @@ class ParameterMetadata(proto.Message):
         param_type (google.cloud.dataflow_v1beta3.types.ParameterType):
             Optional. The type of the parameter.
             Used for selecting input picker.
-        custom_metadata (Sequence[google.cloud.dataflow_v1beta3.types.ParameterMetadata.CustomMetadataEntry]):
+        custom_metadata (Mapping[str, str]):
             Optional. Additional metadata for describing
             this parameter.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    label = proto.Field(proto.STRING, number=2,)
-    help_text = proto.Field(proto.STRING, number=3,)
-    is_optional = proto.Field(proto.BOOL, number=4,)
-    regexes = proto.RepeatedField(proto.STRING, number=5,)
-    param_type = proto.Field(proto.ENUM, number=6, enum="ParameterType",)
-    custom_metadata = proto.MapField(proto.STRING, proto.STRING, number=7,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    label = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    help_text = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    is_optional = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
+    regexes = proto.RepeatedField(
+        proto.STRING,
+        number=5,
+    )
+    param_type = proto.Field(
+        proto.ENUM,
+        number=6,
+        enum="ParameterType",
+    )
+    custom_metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=7,
+    )
 
 
 class TemplateMetadata(proto.Message):
@@ -424,10 +653,18 @@ class TemplateMetadata(proto.Message):
             The parameters for the template.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    description = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     parameters = proto.RepeatedField(
-        proto.MESSAGE, number=3, message="ParameterMetadata",
+        proto.MESSAGE,
+        number=3,
+        message="ParameterMetadata",
     )
 
 
@@ -447,8 +684,15 @@ class SDKInfo(proto.Message):
         JAVA = 1
         PYTHON = 2
 
-    language = proto.Field(proto.ENUM, number=1, enum=Language,)
-    version = proto.Field(proto.STRING, number=2,)
+    language = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=Language,
+    )
+    version = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class RuntimeMetadata(proto.Message):
@@ -461,15 +705,23 @@ class RuntimeMetadata(proto.Message):
             The parameters for the template.
     """
 
-    sdk_info = proto.Field(proto.MESSAGE, number=1, message="SDKInfo",)
+    sdk_info = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="SDKInfo",
+    )
     parameters = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="ParameterMetadata",
+        proto.MESSAGE,
+        number=2,
+        message="ParameterMetadata",
     )
 
 
 class CreateJobFromTemplateRequest(proto.Message):
     r"""A request to create a Cloud Dataflow job from a template.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         project_id (str):
             Required. The ID of the Cloud Platform
@@ -481,7 +733,9 @@ class CreateJobFromTemplateRequest(proto.Message):
             Required. A Cloud Storage path to the template from which to
             create the job. Must be a valid Cloud Storage URL, beginning
             with ``gs://``.
-        parameters (Sequence[google.cloud.dataflow_v1beta3.types.CreateJobFromTemplateRequest.ParametersEntry]):
+
+            This field is a member of `oneof`_ ``template``.
+        parameters (Mapping[str, str]):
             The runtime parameters to pass to the job.
         environment (google.cloud.dataflow_v1beta3.types.RuntimeEnvironment):
             The runtime environment for the job.
@@ -491,17 +745,40 @@ class CreateJobFromTemplateRequest(proto.Message):
             to which to direct the request.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    job_name = proto.Field(proto.STRING, number=4,)
-    gcs_path = proto.Field(proto.STRING, number=2, oneof="template",)
-    parameters = proto.MapField(proto.STRING, proto.STRING, number=3,)
-    environment = proto.Field(proto.MESSAGE, number=5, message="RuntimeEnvironment",)
-    location = proto.Field(proto.STRING, number=6,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    job_name = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    gcs_path = proto.Field(
+        proto.STRING,
+        number=2,
+        oneof="template",
+    )
+    parameters = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=3,
+    )
+    environment = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="RuntimeEnvironment",
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class GetTemplateRequest(proto.Message):
     r"""A request to retrieve a Cloud Dataflow job template.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         project_id (str):
             Required. The ID of the Cloud Platform
@@ -511,6 +788,8 @@ class GetTemplateRequest(proto.Message):
             template from which to create the job.
             Must be valid Cloud Storage URL, beginning with
             'gs://'.
+
+            This field is a member of `oneof`_ ``template``.
         view (google.cloud.dataflow_v1beta3.types.GetTemplateRequest.TemplateView):
             The view to retrieve. Defaults to METADATA_ONLY.
         location (str):
@@ -523,10 +802,24 @@ class GetTemplateRequest(proto.Message):
         r"""The various views of a template that may be retrieved."""
         METADATA_ONLY = 0
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    gcs_path = proto.Field(proto.STRING, number=2, oneof="template",)
-    view = proto.Field(proto.ENUM, number=3, enum=TemplateView,)
-    location = proto.Field(proto.STRING, number=4,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    gcs_path = proto.Field(
+        proto.STRING,
+        number=2,
+        oneof="template",
+    )
+    view = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=TemplateView,
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class GetTemplateResponse(proto.Message):
@@ -552,10 +845,26 @@ class GetTemplateResponse(proto.Message):
         LEGACY = 1
         FLEX = 2
 
-    status = proto.Field(proto.MESSAGE, number=1, message=status_pb2.Status,)
-    metadata = proto.Field(proto.MESSAGE, number=2, message="TemplateMetadata",)
-    template_type = proto.Field(proto.ENUM, number=3, enum=TemplateType,)
-    runtime_metadata = proto.Field(proto.MESSAGE, number=4, message="RuntimeMetadata",)
+    status = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=status_pb2.Status,
+    )
+    metadata = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="TemplateMetadata",
+    )
+    template_type = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=TemplateType,
+    )
+    runtime_metadata = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="RuntimeMetadata",
+    )
 
 
 class LaunchTemplateParameters(proto.Message):
@@ -565,7 +874,7 @@ class LaunchTemplateParameters(proto.Message):
         job_name (str):
             Required. The job name to use for the created
             job.
-        parameters (Sequence[google.cloud.dataflow_v1beta3.types.LaunchTemplateParameters.ParametersEntry]):
+        parameters (Mapping[str, str]):
             The runtime parameters to pass to the job.
         environment (google.cloud.dataflow_v1beta3.types.RuntimeEnvironment):
             The runtime environment for the job.
@@ -573,23 +882,48 @@ class LaunchTemplateParameters(proto.Message):
             If set, replace the existing pipeline with
             the name specified by jobName with this
             pipeline, preserving state.
-        transform_name_mapping (Sequence[google.cloud.dataflow_v1beta3.types.LaunchTemplateParameters.TransformNameMappingEntry]):
+        transform_name_mapping (Mapping[str, str]):
             Only applicable when updating a pipeline. Map
             of transform name prefixes of the job to be
             replaced to the corresponding name prefixes of
             the new job.
     """
 
-    job_name = proto.Field(proto.STRING, number=1,)
-    parameters = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    environment = proto.Field(proto.MESSAGE, number=3, message="RuntimeEnvironment",)
-    update = proto.Field(proto.BOOL, number=4,)
-    transform_name_mapping = proto.MapField(proto.STRING, proto.STRING, number=5,)
+    job_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    parameters = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    environment = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="RuntimeEnvironment",
+    )
+    update = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
+    transform_name_mapping = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=5,
+    )
 
 
 class LaunchTemplateRequest(proto.Message):
     r"""A request to launch a template.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         project_id (str):
             Required. The ID of the Cloud Platform
@@ -602,8 +936,12 @@ class LaunchTemplateRequest(proto.Message):
             which to create the job.
             Must be valid Cloud Storage URL, beginning with
             'gs://'.
+
+            This field is a member of `oneof`_ ``template``.
         dynamic_template (google.cloud.dataflow_v1beta3.types.DynamicTemplateLaunchParams):
             Params for launching a dynamic template.
+
+            This field is a member of `oneof`_ ``template``.
         launch_parameters (google.cloud.dataflow_v1beta3.types.LaunchTemplateParameters):
             The parameters of the template to launch.
             This should be part of the body of the POST
@@ -614,9 +952,19 @@ class LaunchTemplateRequest(proto.Message):
             to which to direct the request.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    validate_only = proto.Field(proto.BOOL, number=2,)
-    gcs_path = proto.Field(proto.STRING, number=3, oneof="template",)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    validate_only = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
+    gcs_path = proto.Field(
+        proto.STRING,
+        number=3,
+        oneof="template",
+    )
     dynamic_template = proto.Field(
         proto.MESSAGE,
         number=6,
@@ -624,9 +972,14 @@ class LaunchTemplateRequest(proto.Message):
         message="DynamicTemplateLaunchParams",
     )
     launch_parameters = proto.Field(
-        proto.MESSAGE, number=4, message="LaunchTemplateParameters",
+        proto.MESSAGE,
+        number=4,
+        message="LaunchTemplateParameters",
+    )
+    location = proto.Field(
+        proto.STRING,
+        number=5,
     )
-    location = proto.Field(proto.STRING, number=5,)
 
 
 class LaunchTemplateResponse(proto.Message):
@@ -639,7 +992,11 @@ class LaunchTemplateResponse(proto.Message):
             launched.
     """
 
-    job = proto.Field(proto.MESSAGE, number=1, message=jobs.Job,)
+    job = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=jobs.Job,
+    )
 
 
 class InvalidTemplateParameters(proto.Message):
@@ -663,11 +1020,19 @@ class InvalidTemplateParameters(proto.Message):
                 validate.
         """
 
-        parameter = proto.Field(proto.STRING, number=1,)
-        description = proto.Field(proto.STRING, number=2,)
+        parameter = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        description = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
     parameter_violations = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=ParameterViolation,
+        proto.MESSAGE,
+        number=1,
+        message=ParameterViolation,
     )
 
 
@@ -685,8 +1050,14 @@ class DynamicTemplateLaunchParams(proto.Message):
             Cloud Storage URL, beginning with ``gs://``.
     """
 
-    gcs_path = proto.Field(proto.STRING, number=1,)
-    staging_location = proto.Field(proto.STRING, number=2,)
+    gcs_path = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    staging_location = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
