@@ -13,9 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import math
 import os
 
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
+
+import math
+
 from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
@@ -25,7 +33,6 @@ from google.auth.exceptions import MutualTLSChannelError
 from google.oauth2 import service_account
 import grpc
 from grpc.experimental import aio
-import mock
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 import pytest
 
